@@ -35,7 +35,7 @@ else:
 lib = ffi.dlopen(soname)
 
 __xcb_proto_version__ = "1.17.0"
-__version__ = "1.8.0"
+__version__ = "1.9.0"
 
 X_PROTOCOL = lib.X_PROTOCOL
 X_PROTOCOL_REVISION = lib.X_PROTOCOL_REVISION
@@ -292,6 +292,21 @@ class Protobj(object):
         if unpacker.known_max is not None:
             self.bufsize = unpacker.known_max
 
+    def __repr__(self):
+        guts = []
+        for k in dir(self):
+            # skip all the python generated gunk
+            if k.startswith("__"):
+                continue
+
+            attr = getattr(self, k)
+            # skip synthetic(), pack(), etc.
+            if callable(attr):
+                continue
+
+            guts.append(f"{k}={attr}")
+        return f"{self.__class__.__qualname__}({', '.join(guts)})"
+
 
 class Buffer(Protobj):
     def __init__(self, unpacker):
