@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 1
 MINOR_VERSION = 0
@@ -11,7 +10,6 @@ _errors = {}
 from . import xproto
 
 
-@dataclass(init=False)
 class SwapAction:
     Undefined = 0
     Background = 1
@@ -19,7 +17,6 @@ class SwapAction:
     Copied = 3
 
 
-@dataclass(init=False)
 class SwapInfo(xcffib.Struct):
     xge = False
 
@@ -46,7 +43,6 @@ class SwapInfo(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class BufferAttributes(xcffib.Struct):
     xge = False
 
@@ -72,7 +68,6 @@ class BufferAttributes(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class VisualInfo(xcffib.Struct):
     xge = False
 
@@ -100,7 +95,6 @@ class VisualInfo(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class VisualInfos(xcffib.Struct):
     xge = False
 
@@ -127,7 +121,6 @@ class VisualInfos(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class BadBufferError(xcffib.Error):
     xge = False
 
@@ -150,7 +143,6 @@ BadBadBuffer = BadBufferError
 _errors[0] = BadBufferError
 
 
-@dataclass(init=False)
 class QueryVersionReply(xcffib.Reply):
     xge = False
 
@@ -163,12 +155,10 @@ class QueryVersionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 
 
-@dataclass(init=False)
 class GetVisualInfoReply(xcffib.Reply):
     xge = False
 
@@ -184,12 +174,10 @@ class GetVisualInfoReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetVisualInfoCookie(xcffib.Cookie):
     reply_type = GetVisualInfoReply
 
 
-@dataclass(init=False)
 class GetBackBufferAttributesReply(xcffib.Reply):
     xge = False
 
@@ -204,12 +192,10 @@ class GetBackBufferAttributesReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetBackBufferAttributesCookie(xcffib.Cookie):
     reply_type = GetBackBufferAttributesReply
 
 
-@dataclass(init=False)
 class dbeExtension(xcffib.Extension):
     def QueryVersion(self, major_version, minor_version, is_checked=True):
         buf = io.BytesIO()
