@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 1
 MINOR_VERSION = 4
@@ -11,7 +10,6 @@ _errors = {}
 from . import xproto
 
 
-@dataclass(init=False)
 class QueryVersionReply(xcffib.Reply):
     xge = False
 
@@ -24,12 +22,10 @@ class QueryVersionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 
 
-@dataclass(init=False)
 class OpenReply(xcffib.Reply):
     xge = False
 
@@ -42,12 +38,10 @@ class OpenReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class OpenCookie(xcffib.Cookie):
     reply_type = OpenReply
 
 
-@dataclass(init=False)
 class BufferFromPixmapReply(xcffib.Reply):
     xge = False
 
@@ -68,12 +62,10 @@ class BufferFromPixmapReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class BufferFromPixmapCookie(xcffib.Cookie):
     reply_type = BufferFromPixmapReply
 
 
-@dataclass(init=False)
 class FDFromFenceReply(xcffib.Reply):
     xge = False
 
@@ -86,12 +78,10 @@ class FDFromFenceReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class FDFromFenceCookie(xcffib.Cookie):
     reply_type = FDFromFenceReply
 
 
-@dataclass(init=False)
 class dri3Extension(xcffib.Extension):
     def QueryVersion(self, major_version, minor_version, is_checked=True):
         buf = io.BytesIO()
