@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 1
 MINOR_VERSION = 1
@@ -10,7 +9,6 @@ _events = {}
 _errors = {}
 
 
-@dataclass(init=False)
 class GetVersionReply(xcffib.Reply):
     xge = False
 
@@ -25,12 +23,10 @@ class GetVersionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetVersionCookie(xcffib.Cookie):
     reply_type = GetVersionReply
 
 
-@dataclass(init=False)
 class GetXIDRangeReply(xcffib.Reply):
     xge = False
 
@@ -43,12 +39,10 @@ class GetXIDRangeReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetXIDRangeCookie(xcffib.Cookie):
     reply_type = GetXIDRangeReply
 
 
-@dataclass(init=False)
 class GetXIDListReply(xcffib.Reply):
     xge = False
 
@@ -62,12 +56,10 @@ class GetXIDListReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetXIDListCookie(xcffib.Cookie):
     reply_type = GetXIDListReply
 
 
-@dataclass(init=False)
 class xc_miscExtension(xcffib.Extension):
     def GetVersion(self, client_major_version, client_minor_version, is_checked=True):
         buf = io.BytesIO()
