@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 6
 MINOR_VERSION = 0
@@ -13,7 +12,6 @@ from . import render
 from . import shape
 
 
-@dataclass(init=False)
 class QueryVersionReply(xcffib.Reply):
     xge = False
 
@@ -26,44 +24,37 @@ class QueryVersionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 
 
-@dataclass(init=False)
 class SaveSetMode:
     Insert = 0
     Delete = 1
 
 
-@dataclass(init=False)
 class SaveSetTarget:
     Nearest = 0
     Root = 1
 
 
-@dataclass(init=False)
 class SaveSetMapping:
     Map = 0
     Unmap = 1
 
 
-@dataclass(init=False)
 class SelectionEvent:
     SetSelectionOwner = 0
     SelectionWindowDestroy = 1
     SelectionClientClose = 2
 
 
-@dataclass(init=False)
 class SelectionEventMask:
     SetSelectionOwner = 1 << 0
     SelectionWindowDestroy = 1 << 1
     SelectionClientClose = 1 << 2
 
 
-@dataclass(init=False)
 class SelectionNotifyEvent(xcffib.Event):
     xge = False
 
@@ -118,17 +109,14 @@ class SelectionNotifyEvent(xcffib.Event):
 _events[0] = SelectionNotifyEvent
 
 
-@dataclass(init=False)
 class CursorNotify:
     DisplayCursor = 0
 
 
-@dataclass(init=False)
 class CursorNotifyMask:
     DisplayCursor = 1 << 0
 
 
-@dataclass(init=False)
 class CursorNotifyEvent(xcffib.Event):
     xge = False
 
@@ -174,7 +162,6 @@ class CursorNotifyEvent(xcffib.Event):
 _events[1] = CursorNotifyEvent
 
 
-@dataclass(init=False)
 class GetCursorImageReply(xcffib.Reply):
     xge = False
 
@@ -196,12 +183,10 @@ class GetCursorImageReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetCursorImageCookie(xcffib.Cookie):
     reply_type = GetCursorImageReply
 
 
-@dataclass(init=False)
 class BadRegionError(xcffib.Error):
     xge = False
 
@@ -224,12 +209,10 @@ BadBadRegion = BadRegionError
 _errors[0] = BadRegionError
 
 
-@dataclass(init=False)
 class Region:
     _None = 0
 
 
-@dataclass(init=False)
 class FetchRegionReply(xcffib.Reply):
     xge = False
 
@@ -246,12 +229,10 @@ class FetchRegionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class FetchRegionCookie(xcffib.Cookie):
     reply_type = FetchRegionReply
 
 
-@dataclass(init=False)
 class GetCursorNameReply(xcffib.Reply):
     xge = False
 
@@ -265,12 +246,10 @@ class GetCursorNameReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetCursorNameCookie(xcffib.Cookie):
     reply_type = GetCursorNameReply
 
 
-@dataclass(init=False)
 class GetCursorImageAndNameReply(xcffib.Reply):
     xge = False
 
@@ -296,12 +275,10 @@ class GetCursorImageAndNameReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetCursorImageAndNameCookie(xcffib.Cookie):
     reply_type = GetCursorImageAndNameReply
 
 
-@dataclass(init=False)
 class BarrierDirections:
     PositiveX = 1 << 0
     PositiveY = 1 << 1
@@ -309,13 +286,11 @@ class BarrierDirections:
     NegativeY = 1 << 3
 
 
-@dataclass(init=False)
 class ClientDisconnectFlags:
     Default = 0
     Terminate = 1 << 0
 
 
-@dataclass(init=False)
 class GetClientDisconnectModeReply(xcffib.Reply):
     xge = False
 
@@ -328,12 +303,10 @@ class GetClientDisconnectModeReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetClientDisconnectModeCookie(xcffib.Cookie):
     reply_type = GetClientDisconnectModeReply
 
 
-@dataclass(init=False)
 class xfixesExtension(xcffib.Extension):
     def QueryVersion(self, client_major_version, client_minor_version, is_checked=True):
         buf = io.BytesIO()
