@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 1
 MINOR_VERSION = 0
@@ -11,7 +10,6 @@ _errors = {}
 from . import xproto
 
 
-@dataclass(init=False)
 class PRINTER(xcffib.Struct):
     xge = False
 
@@ -55,20 +53,17 @@ class PRINTER(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class GetDoc:
     Finished = 0
     SecondConsumer = 1
 
 
-@dataclass(init=False)
 class EvMask:
     NoEventMask = 0
     PrintMask = 1 << 0
     AttributeMask = 1 << 1
 
 
-@dataclass(init=False)
 class Detail:
     StartJobNotify = 1
     EndJobNotify = 2
@@ -78,7 +73,6 @@ class Detail:
     EndPageNotify = 6
 
 
-@dataclass(init=False)
 class Attr:
     JobAttr = 1
     DocAttr = 2
@@ -89,7 +83,6 @@ class Attr:
     SpoolerAttr = 7
 
 
-@dataclass(init=False)
 class PrintQueryVersionReply(xcffib.Reply):
     xge = False
 
@@ -102,12 +95,10 @@ class PrintQueryVersionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class PrintQueryVersionCookie(xcffib.Cookie):
     reply_type = PrintQueryVersionReply
 
 
-@dataclass(init=False)
 class PrintGetPrinterListReply(xcffib.Reply):
     xge = False
 
@@ -121,12 +112,10 @@ class PrintGetPrinterListReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class PrintGetPrinterListCookie(xcffib.Cookie):
     reply_type = PrintGetPrinterListReply
 
 
-@dataclass(init=False)
 class PrintGetContextReply(xcffib.Reply):
     xge = False
 
@@ -139,12 +128,10 @@ class PrintGetContextReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class PrintGetContextCookie(xcffib.Cookie):
     reply_type = PrintGetContextReply
 
 
-@dataclass(init=False)
 class PrintGetScreenOfContextReply(xcffib.Reply):
     xge = False
 
@@ -157,12 +144,10 @@ class PrintGetScreenOfContextReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class PrintGetScreenOfContextCookie(xcffib.Cookie):
     reply_type = PrintGetScreenOfContextReply
 
 
-@dataclass(init=False)
 class PrintGetDocumentDataReply(xcffib.Reply):
     xge = False
 
@@ -178,12 +163,10 @@ class PrintGetDocumentDataReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class PrintGetDocumentDataCookie(xcffib.Cookie):
     reply_type = PrintGetDocumentDataReply
 
 
-@dataclass(init=False)
 class PrintInputSelectedReply(xcffib.Reply):
     xge = False
 
@@ -196,12 +179,10 @@ class PrintInputSelectedReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class PrintInputSelectedCookie(xcffib.Cookie):
     reply_type = PrintInputSelectedReply
 
 
-@dataclass(init=False)
 class PrintGetAttributesReply(xcffib.Reply):
     xge = False
 
@@ -215,12 +196,10 @@ class PrintGetAttributesReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class PrintGetAttributesCookie(xcffib.Cookie):
     reply_type = PrintGetAttributesReply
 
 
-@dataclass(init=False)
 class PrintGetOneAttributesReply(xcffib.Reply):
     xge = False
 
@@ -234,12 +213,10 @@ class PrintGetOneAttributesReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class PrintGetOneAttributesCookie(xcffib.Cookie):
     reply_type = PrintGetOneAttributesReply
 
 
-@dataclass(init=False)
 class PrintGetPageDimensionsReply(xcffib.Reply):
     xge = False
 
@@ -259,12 +236,10 @@ class PrintGetPageDimensionsReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class PrintGetPageDimensionsCookie(xcffib.Cookie):
     reply_type = PrintGetPageDimensionsReply
 
 
-@dataclass(init=False)
 class PrintQueryScreensReply(xcffib.Reply):
     xge = False
 
@@ -278,12 +253,10 @@ class PrintQueryScreensReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class PrintQueryScreensCookie(xcffib.Cookie):
     reply_type = PrintQueryScreensReply
 
 
-@dataclass(init=False)
 class PrintSetImageResolutionReply(xcffib.Reply):
     xge = False
 
@@ -296,12 +269,10 @@ class PrintSetImageResolutionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class PrintSetImageResolutionCookie(xcffib.Cookie):
     reply_type = PrintSetImageResolutionReply
 
 
-@dataclass(init=False)
 class PrintGetImageResolutionReply(xcffib.Reply):
     xge = False
 
@@ -314,12 +285,10 @@ class PrintGetImageResolutionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class PrintGetImageResolutionCookie(xcffib.Cookie):
     reply_type = PrintGetImageResolutionReply
 
 
-@dataclass(init=False)
 class NotifyEvent(xcffib.Event):
     xge = False
 
@@ -352,7 +321,6 @@ class NotifyEvent(xcffib.Event):
 _events[0] = NotifyEvent
 
 
-@dataclass(init=False)
 class AttributNotifyEvent(xcffib.Event):
     xge = False
 
@@ -384,7 +352,6 @@ class AttributNotifyEvent(xcffib.Event):
 _events[1] = AttributNotifyEvent
 
 
-@dataclass(init=False)
 class BadContextError(xcffib.Error):
     xge = False
 
@@ -407,7 +374,6 @@ BadBadContext = BadContextError
 _errors[0] = BadContextError
 
 
-@dataclass(init=False)
 class BadSequenceError(xcffib.Error):
     xge = False
 
@@ -430,7 +396,6 @@ BadBadSequence = BadSequenceError
 _errors[1] = BadSequenceError
 
 
-@dataclass(init=False)
 class xprintExtension(xcffib.Extension):
     def PrintQueryVersion(self, is_checked=True):
         buf = io.BytesIO()
