@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 1
 MINOR_VERSION = 1
@@ -11,7 +10,6 @@ _errors = {}
 from . import xv
 
 
-@dataclass(init=False)
 class SurfaceInfo(xcffib.Struct):
     xge = False
 
@@ -79,7 +77,6 @@ class SurfaceInfo(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class QueryVersionReply(xcffib.Reply):
     xge = False
 
@@ -92,12 +89,10 @@ class QueryVersionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 
 
-@dataclass(init=False)
 class ListSurfaceTypesReply(xcffib.Reply):
     xge = False
 
@@ -111,12 +106,10 @@ class ListSurfaceTypesReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class ListSurfaceTypesCookie(xcffib.Cookie):
     reply_type = ListSurfaceTypesReply
 
 
-@dataclass(init=False)
 class CreateContextReply(xcffib.Reply):
     xge = False
 
@@ -132,12 +125,10 @@ class CreateContextReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class CreateContextCookie(xcffib.Cookie):
     reply_type = CreateContextReply
 
 
-@dataclass(init=False)
 class CreateSurfaceReply(xcffib.Reply):
     xge = False
 
@@ -151,12 +142,10 @@ class CreateSurfaceReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class CreateSurfaceCookie(xcffib.Cookie):
     reply_type = CreateSurfaceReply
 
 
-@dataclass(init=False)
 class CreateSubpictureReply(xcffib.Reply):
     xge = False
 
@@ -178,12 +167,10 @@ class CreateSubpictureReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class CreateSubpictureCookie(xcffib.Cookie):
     reply_type = CreateSubpictureReply
 
 
-@dataclass(init=False)
 class ListSubpictureTypesReply(xcffib.Reply):
     xge = False
 
@@ -197,12 +184,10 @@ class ListSubpictureTypesReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class ListSubpictureTypesCookie(xcffib.Cookie):
     reply_type = ListSubpictureTypesReply
 
 
-@dataclass(init=False)
 class xvmcExtension(xcffib.Extension):
     def QueryVersion(self, is_checked=True):
         buf = io.BytesIO()
